@@ -5,6 +5,7 @@ import requests
 from django import forms
 from sentry.plugins.bases import notify
 
+
 WECHAT_WEBHOOK_URL = "https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key={key}"
 
 
@@ -29,7 +30,7 @@ class WechatWebhookOptionsForm(notify.NotificationConfigurationForm):
 class MultiWechatWebhookPlugin(notify.NotificationPlugin):
     author = 'badx'
     author_url = 'https://github.com/badx/sentry-multi-webhook'
-    version = '0.0.15'
+    version = '0.0.17'
     description = u'Sentry 企业微信 Webhook 插件'
     resource_links = [
         ('Source', 'https://github.com/badx/sentry-multi-webhook'),
@@ -47,6 +48,7 @@ class MultiWechatWebhookPlugin(notify.NotificationPlugin):
         return bool(self.get_option('key', project))
 
     def notify_users(self, group, event, fail_silently=False, **kwargs):
+        print("notify_users")
         key = self.get_option('key', group.project)
         prod_key = self.get_option("prod_key", group.project) or key
         noticeUser = self.get_option("noticeUser", group.project)
@@ -62,13 +64,17 @@ class MultiWechatWebhookPlugin(notify.NotificationPlugin):
                                         (("(%s)" % environment) if (not slug.endswith("prod") and
                                                          not slug.endswith("int")
                                                          and environment) else ""))
+        level = event.get_tag("level") or ""
+        description = event.title or event.message
 
         data = {
             "msgtype": "markdown",
             "markdown": {
-                "content": u"#### {title} \n > {message} \n [查看]({url})".format(
+                "content": u"#### {title} \n 环境: <font color=\"info\">{environment}</font> \n > 等级: <font color=\"warning\">{level}</font> \n > {message} \n [查看]({url})".format(
                     title=title,
-                    message=event.message,
+                    environment=environment,
+                    level=level,
+                    message=description,
                     url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                 ) + ("\n<@{noticeUser}>".format(noticeUser=noticeUser.replace(",", ",@")) if noticeUser else "")
             }
